preprocessings = {
    'county': {
        'income': {
            'lambdas': {
                'County': lambda x: x[:-7],  # removing county word
            },
            'rename': {
                'County': 'county',
                'State_ab': 'state',
                'Place': 'place',
                'Type': 'type',
                'Primary': 'primary_type',
                'Area_Code': 'area_code',
                'ALand': 'land_area',
                'AWater': 'land_water',
                'Lat': 'latitude',
                'Lon': 'longtitude',
                'Mean': 'income_mean',
                'Median': 'income_median',
                'Stdev': 'income_std'
            },
            'remove': [
                'State_Code',
                'State_Name',
                'id',
                'sum_w',
                'latitude',
                'longtitude',
                'Zip_Code',
                'type',
                'place',
                'primary_type',
                'City',
                'area_code',
            ]
        },
        'census_full': {
            'lambdas': {
                'State': lambda x: state_abbreviations[x],
                'County': lambda x: x[:-7]
            },
            'rename': {
                'State': 'state',
                'County': 'county',
                'TotalPop': 'total_population',
                'Men': 'number_of_men',
                'Women': 'number_of_women',
                'Hispanic': 'race_hispanic',
                'White': 'race_white',
                'Black': 'race_black',
                'Native': 'race_native',
                'Asian': 'race_asian',
                'Pacific': 'pacific',
                'VotingAgeCitizen': 'voting_age_citizens',
                'Income': 'census_income_average',
                'IncomeErr': 'census_income_margin',
                'IncomePerCap': 'census_income_per_capita',
                'IncomePerCapErr': 'census_income_per_capita_margin',
                'Poverty': 'census_poverty',
                'ChildPoverty': 'census_child_poverty',
                'Professional': 'professional_job_percentage',
                'Service': 'service_job_percentage',
                'Office': 'office_job_percentage',
                'Construction': 'construction_job_percentage',
                'Production': 'production_job_percentage',
                'Drive': 'commute_drive_percentage',
                'Carpool': 'commute_carpool_percentage',
                'Transit': 'commute_transit_percentage',
                'Walk': 'commute_walk_percentage',
                'OtherTransp': 'commute_other_percentage',
                'WorkAtHome': 'commute_noneed_percentage',
                'Employed': 'number_of_employed_people',
                'PrivateWork': 'employment_private_percentage',
                'PublicWork': 'employment_public_percentage',
                'SelfEmployed': 'employment_self_percentage',
                'FamilyWork': 'employment_family_percentage',
                'Unemployment': 'unemployment_percentage'
            },
            'remove': ['MeanCommute', 'CountyId']
        },
        'diversityindex': {
            'lambdas': {
            },
            'rename': {
                'Diversity-Index': 'diversity_index',
                'Black or African American alone, percent, 2013': 'diversity_black_race',
                'American Indian and Alaska Native alone, percent, 2013': 'diversity_native_race',
                'Asian alone, percent, 2013': 'diversity_asian_race',
                'Native Hawaiian and Other Pacific Islander alone, percent,': 'diversity_pacific_race',
                'Two or More Races, percent, 2013': 'diversity_two_or_more_races',
                'Hispanic or Latino, percent, 2013': 'diversity_hispanic_race',
                'White alone, not Hispanic or Latino, percent, 2013': 'diversity_white_race'
            },
            'remove': []
        },
        'mortality': {
            'lambdas': {
            },
            'rename': {'Location': 'county'},
            'remove': ['FIPS']
        },
        'election': {
            'lambdas': {},
            'rename': {},
            'remove': ['FIPS'],
        },
        'icu_beds': {
            'lambdas': {},
            'rename': {'County': 'county', 'State': 'state', 'ICU Beds': 'icu_beds'},
            'remove': [],
        },
        'land_and_water': {
            'lambdas': {'NAME': lambda x: x[:-7] if x.endswith('County') else x},
            'rename': {'USPS': 'state', 'NAME': 'county'},
            'remove': ['GEOID', 'ANSICODE'],
        },
        'cases': {
            'lambdas': {},
            'rename': {'county_name': 'county', 'state_name': 'state'},
            'remove': []
        }

    }
}

state_abbreviations = {'Armed Forces (the) Americas': 'AA',
                       'Alberta': 'AB',
                       'Armed Forces Europe': 'AE',
                       'Alaska': 'AK',
                       'Alabama': 'AL',
                       'Armed Forces Pacific': 'AP',
                       'Arkansas': 'AR',
                       'American Samoa': 'AS',
                       'Arizona': 'AZ',
                       'British Columbia': 'BC',
                       'California': 'CA',
                       'Canada': 'CD',
                       'Colorado': 'CO',
                       'Connecticut': 'CT',
                       'Dist. Of Columbia': 'DC',
                       'Delaware': 'DE',
                       'Foreign Countries': 'FF',
                       'Florida': 'FL',
                       'Georgia': 'GA',
                       'Guam': 'GU',
                       'Hawaii': 'HI',
                       'Iowa': 'IA',
                       'Idaho': 'ID',
                       'Illinois': 'IL',
                       'Indiana': 'IN',
                       'Kansas': 'KS',
                       'Kentucky': 'KY',
                       'Louisiana': 'LA',
                       'Massachusetts': 'MA',
                       'Manitoba': 'MB',
                       'Maryland': 'MD',
                       'Maine': 'ME',
                       'Michigan': 'MI',
                       'Minnesota': 'MN',
                       'Missouri': 'MO',
                       'Mississippi': 'MS',
                       'Montana': 'MT',
                       'Mexico': 'MX',
                       'New Brunswick': 'NB',
                       'North Carolina': 'NC',
                       'North Dakota': 'ND',
                       'Nebraska': 'NE',
                       'New Hampshire': 'NH',
                       'New Jersey': 'NJ',
                       'Newfoundland and Labrador': 'NL',
                       'New Mexico': 'NM',
                       'Nova Scotia': 'NS',
                       'Northwest Territories': 'NT',
                       'Nunavut': 'NU',
                       'Nevada': 'NV',
                       'New York': 'NY',
                       'Ohio': 'OH',
                       'Oklahoma': 'OK',
                       'Ontario': 'ON',
                       'Oregon': 'OR',
                       'Pennsylvania': 'PA',
                       'Prince Edward Island': 'PE',
                       'Puerto Rico': 'PR',
                       'Quebec': 'QC',
                       'Rhode Island': 'RI',
                       'South Carolina': 'SC',
                       'South Dakota': 'SD',
                       'Saskatchewan': 'SK',
                       'Tennessee': 'TN',
                       'Trust Territory': 'TT',
                       'Texas': 'TX',
                       'Unknown': 'UN',
                       'Utah': 'UT',
                       'Virginia': 'VA',
                       'Virgin Islands': 'VI',
                       'Vermont': 'VT',
                       'Washington': 'WA',
                       'Wisconsin': 'WI',
                       'West Virginia': 'WV',
                       'Wyoming': 'WY',
                       'Yukon': 'YT',
                       'District of Columbia': "District of Columbia"
                       }

label2description = {
    'county': 'US County',
    'state': 'US State',
    'min_confirmed_count': 'Minimum Confirmed COVID-19 Cases',
    'min_death_count': 'Minimum COVID-19 Death Counts',
    'max_confirmed_count': 'Maximum Confirmed COVID-19 Cases',
    'max_death_count': 'Maximum COVID-19 Death Counts',
    'median_confirmed_count': 'Median of Confirmed COVID-19 Cases',
    'median_death_count': 'Median COVID-19 Death Counts',
    'mean_confirmed_count': 'Mean of Confirmed COVID-19 Cases',
    'mean_death_count': 'Mean of COVID-19 Death Counts',
    'sum_confirmed_count': 'Sum of Confirmed COVID-19 Cases',
    'sum_death_count': 'Sum of COVID-19 Death Counts',
    'total_population': 'Total County Population',
    'number_of_men': 'Number of Men in the County',
    'number_of_women': 'Number of Women in the County',
    'race_hispanic': 'Hispanic Race Ratio',
    'race_white': 'White Race Ratio',
    'race_black': 'Black Race Ratio',
    'race_native': 'Native American Race Ratio',
    'race_asian': 'Asian Race Ratio',
    'pacific': 'Pacific Islander Race Ratio',
    'voting_age_citizens': 'Number of Voting-age Citizens in the County',
    'census_income_average': 'Average Income in the County - Based on US Census',
    'census_income_margin': 'Income Margin in the County - Based on US Census',
    'census_income_per_capita': 'Average Income per Capita in the County - Based on US Census',
    'census_income_per_capita_margin': 'Income per Capita Margin in the County - Based on US Census',
    'census_poverty': 'Poverty',
    'census_child_poverty': 'Child Poverty',
    'professional_job_percentage': 'Professional Job Percentage',
    'service_job_percentage': 'Service Job Percentage',
    'office_job_percentage': 'Office Job Percentage',
    'construction_job_percentage': 'Construction Job Percentage',
    'production_job_percentage': 'Production Job Percentage',
    'commute_drive_percentage': 'Commute to Work: Drive (Percentage)',
    'commute_carpool_percentage': 'Commute to Work: Carpool (Percentage)',
    'commute_transit_percentage': 'Commute to Work: Transit (Percentage)',
    'commute_walk_percentage': 'Commute to Work: Walk (Percentage)',
    'commute_other_percentage': 'Commute to Work: Other (Percentage)',
    'commute_noneed_percentage': 'Commute to Work: Work at Home (Percentage)',
    'number_of_employed_people': 'Commute to Work: Driving (Percentage)',
    'employment_private_percentage': 'Private Employment',
    'employment_public_percentage': 'Public Employment Percentage',
    'employment_self_percentage': 'Self Employment Percentage',
    'employment_family_percentage': 'Family Employment Percentage',
    'unemployment_percentage': 'Unemployment Percentage',
    'icu_beds': 'Number of ICU Beds',
    'Total Population': 'Total',
    'Population Aged 60+': 'Senior (above 60 years old) population',
    'Percent of Population Aged 60+': 'Senior (above 60 years old) population percentage',
    'Residents Aged 60+ Per Each ICU Bed': 'Senior (above 60 years old) per each ICU bed',
    'diversity_index': 'Diversity Index',
    'diversity_black_race': 'Diversity Black Race Ratio',
    'diversity_native_race': 'Diversity Native Race Ratio',
    'diversity_asian_race': 'Diversity Asian Race Ratio',
    'diversity_pacific_race': 'Diversity Pacific Islander Race Ratio',
    'diversity_two_or_more_races': 'Diversity Two or More Race Combined Ratio',
    'diversity_hispanic_race': 'Diversity Hispanic Rce Ratio',
    'diversity_white_race': 'Diversity White Race Ratio',
    'democrat': 'Number of Democrat Votes',
    'republican': 'Number of Republican Votes',
    'other': 'Number of votes other than Democrat/Republican',
    'ALAND': 'Land Area',
    'AWATER': 'Water Area',
    'ALAND_SQMI': 'Land Area in Square Miles',
    'AWATER_SQMI': 'Water Area in Square Miles',
    'min_land_area': 'Minimum Land Area',
    'min_land_water': 'Minimum Water Area',
    'min_income_mean': 'Minimum Income Mean',
    'min_income_median': 'Minimum Income Median',
    'min_income_std': 'Minimum Income Deviation',
    'max_land_area': 'Maximum Land Area',
    'max_land_water': 'Maximum Water Area',
    'max_income_mean': 'Maximum Average Income',
    'max_income_median': 'Maximum Median Income',
    'max_income_std': 'Maximum Income Deviation',
    'median_land_area': 'Median Land Area',
    'median_land_water': 'Median Water Area',
    'median_income_mean': 'Median Average Income',
    'median_income_median': 'Median Median Income',
    'median_income_std': 'Median Income Deviation',
    'mean_land_area': 'Average Land Area',
    'mean_land_water': 'Average Water Area',
    'mean_income_mean': 'Average of Average Income',
    'mean_income_median': 'Average of Median Income',
    'mean_income_std': 'Average',
    'sum_land_area': 'Sum of Land Area',
    'sum_land_water': 'Sum of Water Area',
    'sum_income_mean': 'Sum of Average Income',
    'sum_income_median': 'Sum of Median Income',
    'sum_income_std': 'Sum of Income Deviation',
    'mortality_rate': 'Mortality Rate',
    'min_mortality_rate': 'Minimum Mortality Rate',
    'max_mortality_rate': 'Maximum Mortality Rate',
    'change_in_mortality_rate': 'Change in Mortality Rate',
    'min_change_in_mortality_rate': 'Minimum Change in Mortality Rate',
    'max_change_in_mortality_rate': 'Maximum Change in Mortality Rate',
    'location': 'County - State',
    'democrat_percentage': 'Democrat Vote Percentage',
    'republican_percentage': 'Republican Vote Percentage',
    'other_than_democrat_or_republican_percentage': 'Votes other than democrat/republican - Percentage',
    'population_density': 'Population Density',
    'death_count_cumsum': 'Cummulative Sum of Death Count',
    'confirmed_count_cumsum': 'Cummulative Sum of Confirmed Count',
    'normalized_death_count_cumsum': 'Population Normalized Death Count Cumsum per region',
    'normalized_confirmed_count_cumsum': 'Population Normalized Case Count Cumsum per region',
}

plot_domains = {
    'x_or_color': [
        'total_population',
        'number_of_men',
        'number_of_women',
        'race_hispanic',
        'race_white',
        'race_black',
        'race_native',
        'race_asian',
        'pacific',
        'voting_age_citizens',
        'census_income_average',
        'census_income_margin',
        'census_income_per_capita',
        'census_income_per_capita_margin',
        'census_poverty',
        'census_child_poverty',
        'professional_job_percentage',
        'service_job_percentage',
        'office_job_percentage',
        'construction_job_percentage',
        'production_job_percentage',
        'commute_drive_percentage',
        'commute_carpool_percentage',
        'commute_transit_percentage',
        'commute_walk_percentage',
        'commute_other_percentage',
        'commute_noneed_percentage',
        'number_of_employed_people',
        'employment_private_percentage',
        'employment_public_percentage',
        'employment_self_percentage',
        'employment_family_percentage',
        'unemployment_percentage',
        'icu_beds',
        'Total Population',
        'Population Aged 60+',
        'Percent of Population Aged 60+',
        'Residents Aged 60+ Per Each ICU Bed',
        'diversity_index',
        'diversity_black_race',
        'diversity_native_race',
        'diversity_asian_race',
        'diversity_pacific_race',
        'diversity_two_or_more_races',
        'diversity_hispanic_race',
        'diversity_white_race',
        'democrat',
        'republican',
        'other',
        'ALAND',
        'AWATER',
        'ALAND_SQMI',
        'AWATER_SQMI',
        'min_land_area',
        'min_land_water',
        'min_income_mean',
        'min_income_median',
        'min_income_std',
        'max_land_area',
        'max_land_water',
        'max_income_mean',
        'max_income_median',
        'max_income_std',
        'median_land_area',
        'median_land_water',
        'median_income_mean',
        'median_income_median',
        'median_income_std',
        'mean_land_area',
        'mean_land_water',
        'mean_income_mean',
        'mean_income_median',
        'mean_income_std',
        'sum_land_area',
        'sum_land_water',
        'sum_income_mean',
        'sum_income_median',
        'sum_income_std',
        'mortality_rate',
        'min_mortality_rate',
        'max_mortality_rate',
        'change_in_mortality_rate',
        'min_change_in_mortality_rate',
        'max_change_in_mortality_rate',
        'democrat_percentage',
        'republican_percentage',
        'other_than_democrat_or_republican_percentage',
        'population_density',
        'Republican Vote Percentage'
    ],
    'y': ['min_confirmed_count',
          'min_death_count',
          'max_confirmed_count',
          'max_death_count',
          'median_confirmed_count',
          'median_death_count',
          'mean_confirmed_count',
          'mean_death_count',
          'sum_confirmed_count',
          'sum_death_count']
}

main_plot_domain = {
    'x_or_color': [
        'total_population',
        'number_of_men',
        'number_of_women',
        'race_hispanic',
        'race_white',
        'race_black',
        'race_native',
        'race_asian',
        'pacific',
        'voting_age_citizens',
        'census_income_average',
        'census_income_margin',
        'census_income_per_capita',
        'census_income_per_capita_margin',
        'census_poverty',
        'census_child_poverty',
        'professional_job_percentage',
        'service_job_percentage',
        'office_job_percentage',
        'construction_job_percentage',
        'production_job_percentage',
        'commute_drive_percentage',
        'commute_carpool_percentage',
        'commute_transit_percentage',
        'commute_walk_percentage',
        'commute_other_percentage',
        'commute_noneed_percentage',
        'number_of_employed_people',
        'employment_private_percentage',
        'employment_public_percentage',
        'employment_self_percentage',
        'employment_family_percentage',
        'unemployment_percentage',
        'icu_beds',
        'Total Population',
        'Population Aged 60+',
        'Percent of Population Aged 60+',
        'Residents Aged 60+ Per Each ICU Bed',
        'diversity_index',
        'diversity_black_race',
        'diversity_native_race',
        'diversity_asian_race',
        'diversity_pacific_race',
        'diversity_two_or_more_races',
        'diversity_hispanic_race',
        'diversity_white_race',
        'ALAND_SQMI',
        'AWATER_SQMI',
        'mean_land_area',
        'mean_land_water',
        'mean_income_mean',
        'mean_income_median',
        'mean_income_std',
        'mortality_rate',
        'min_mortality_rate',
        'max_mortality_rate',
        'change_in_mortality_rate',
        'min_change_in_mortality_rate',
        'max_change_in_mortality_rate',
        'democrat_percentage',
        'republican_percentage',
        'other_than_democrat_or_republican_percentage',
        'population_density'
    ],
    'y': [
        'max_death_count',
        'max_confirmed_count']
}
